==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebGridEmptyTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridEmptyTemplateContextDescription } from "./WebGridEmptyTemplateContextDescription";
/**
 * @hidden
 */
export let WebGridEmptyTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridEmptyTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridEmptyTemplateContextDescriptionMetadata.a == null) {
                WebGridEmptyTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridEmptyTemplateContextDescriptionMetadata.c(WebGridEmptyTemplateContextDescriptionMetadata.a);
            }
            if (a.j(WebGridEmptyTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridEmptyTemplateContextDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridEmptyTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
        }
        static d(a) {
            WebGridEmptyTemplateContextDescriptionMetadata.b(a);
            a.aa("WebGridEmptyTemplateContext", () => new WebGridEmptyTemplateContextDescription());
            a.z("WebGridEmptyTemplateContext", WebGridEmptyTemplateContextDescriptionMetadata.a);
        }
    }
    WebGridEmptyTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridEmptyTemplateContextDescriptionMetadata, 'WebGridEmptyTemplateContextDescriptionMetadata');
    WebGridEmptyTemplateContextDescriptionMetadata.a = null;
    return WebGridEmptyTemplateContextDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridEmptyTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridEmptyTemplateContextDescription } from "./WebGridEmptyTemplateContextDescription";
/**
 * @hidden
 */
export let WebGridEmptyTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridEmptyTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridEmptyTemplateContextDescriptionMetadata.a == null) {
                WebGridEmptyTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridEmptyTemplateContextDescriptionMetadata.c(WebGridEmptyTemplateContextDescriptionMetadata.a);
            }
            if (a.k(WebGridEmptyTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridEmptyTemplateContextDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridEmptyTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebGridEmptyTemplateContextDescriptionMetadata.b(a);
            a.ac("WebGridEmptyTemplateContext", () => new WebGridEmptyTemplateContextDescription());
            a.ab("WebGridEmptyTemplateContext", WebGridEmptyTemplateContextDescriptionMetadata.a);
        }
    }
    WebGridEmptyTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridEmptyTemplateContextDescriptionMetadata, 'WebGridEmptyTemplateContextDescriptionMetadata');
    WebGridEmptyTemplateContextDescriptionMetadata.a = null;
    return WebGridEmptyTemplateContextDescriptionMetadata;
})();
